What
=====
ZoneMinder Python API and Logger

Documentation & Examples
=========================
Latest documentation is available <a href='https://pyzm.readthedocs.io/en/latest/'>here</a>. The documentation includes a full example.

Features
=========
- API auth using tokens or legacy (manages refresh logins automatically)
- Monitors
- Events with filters
- States
- Configs
- EventNotification callbacks

Limitations
============
* Only for Python3



